==> haskell-special-values-0.1.0.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-B7vn5jyavPm2Mj0JzqvDJE
key:                  special-values-0.1.0.0-B7vn5jyavPm2Mj0JzqvDJE
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  9e0b692417e49d11941b421381396297
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-8.10.4/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/special-values-0.1.0.0
hs-libraries:         HSspecial-values-0.1.0.0-B7vn5jyavPm2Mj0JzqvDJE
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    ieee754-0.8.0-Fa1NJsiKKLb2eXdrTUzFMJ
    scientific-0.3.6.2-gWLiwejpFQI84j5y9KlyG text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-special-values-0.1.0.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-6oA1EJlYMpH978MAQtIuNS
key:                  special-values-0.1.0.0-6oA1EJlYMpH978MAQtIuNS
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  344c8a6d470e72f3b20b8b1325446896
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-8.10.4/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/special-values-0.1.0.0
hs-libraries:         HSspecial-values-0.1.0.0-6oA1EJlYMpH978MAQtIuNS
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    ieee754-0.8.0-Fa1NJsiKKLb2eXdrTUzFMJ
    scientific-0.3.6.2-GEO9oP5SB5GP3PEwvdLEG text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
